Enum network::peer_manager::PeerManagerNotification [−][src]
pub enum PeerManagerNotification {
RecvRpc(PeerId, InboundRpcRequest),
RecvMessage(PeerId, Message),
}Expand description
Notifications sent by PeerManager to upstream actors.
Variants
RecvRpc(PeerId, InboundRpcRequest)A new RPC request has been received from a remote peer.
Tuple Fields of RecvRpc
0: PeerId1: InboundRpcRequestRecvMessage(PeerId, Message)A new message has been received from a remote peer.
Tuple Fields of RecvMessage
0: PeerId1: MessageTrait Implementations